#ifndef APPLICATION_H
#define APPLICATION_H

#include <QAction>
#include <QApplication>
#include <QMainWindow>
#include <QSettings>
#include <QTabWidget>
#include <QToolBar>

#include "configeditor/configeditor.h"
#include "eventeditor/eventeditor.h"
#include "startlisteditor/startlisteditor.h"
#include "tablegenerator/tablegenerator.h"

class XkorApplication : public QApplication
{
	Q_OBJECT
	
	private:
		QMainWindow * mainWindow;
		QTabWidget * tw;
		QAction * openAction, * saveAction, * saveAsAction, * settingsAction;
		QString eventFile, configFile, startListFile, tableGeneratorFile;
		bool eventModified, configModified, startListModified, tableGeneratorModified;
		XkorEventEditor * ee;
		XkorConfigEditor * ce;
		XkorStartListEditor * sle;
		XkorTableGenerator * tg;
		QToolBar * toolBar;
		QSettings * settings;
	private slots:
		void editSettings();
		void openFile();
		void refreshSearchPaths();
		void saveFile();
		void saveFileAs();
		void setConfigFile(QString filename);
		void setConfigModified(bool isModified);
		void setDefaultSettings();
		void setEventFile(QString filename);
		void setEventModified(bool isModified);
		void setStartListFile(QString filename);
		void setStartListModified(bool isModified);
		void setTableGeneratorFile(QString filename);
		void setTableGeneratorModified(bool isModified);
		
		void updateButtons();
		void updateModifiedStatus();
		void updateTitle();
	
	public:
		XkorApplication(int & c, char * * v);
		bool notify(QObject * rec, QEvent * ev);
};

#endif
