#include "configeditor/rpbonuswidget.h"

#include <QHeaderView>
#include "configeditor/rpbonusdelegate.h"

XkorRPBonusWidget::XkorRPBonusWidget()
{
	treeWidget->setColumnCount(2);
	treeWidget->setSortingEnabled(true);
	treeWidget->setItemDelegate(new XkorRPBonusDelegate);
	treeWidget->sortItems(0, Qt::AscendingOrder);
	treeWidget->setHeaderLabels(QStringList() << tr("Nation") << tr("RP bonus"));
	
	// set the column widths
	treeWidget->header()->setResizeMode(0, QHeaderView::Stretch);
	treeWidget->header()->setResizeMode(1, QHeaderView::Fixed);
	treeWidget->header()->resizeSection(1, 100);
	
	setupLayout();
}

std::map<QString, double> XkorRPBonusWidget::bonuses()
{
	std::map<QString, double> rval;
	for(QTreeWidgetItemIterator i(treeWidget); *i; ++i)
		rval[(*i)->text(0)] = (*i)->text(1).toDouble();
	return rval;
}

void XkorRPBonusWidget::initItem(QTreeWidgetItem * item, QString nation, double bonus)
{
	item->setText(0, nation);
	item->setText(1, QString::number(bonus));
}

void XkorRPBonusWidget::setupLayout()
{
	layout = new QGridLayout(this);
	layout->addWidget(treeWidget, 0, 0, 5, 1);
	layout->addWidget(insertButton, 1, 1);
	layout->addWidget(deleteButton, 3, 1);
}

void XkorRPBonusWidget::setBonuses(std::map<QString, double> bonuses)
{
	clear();
	for(std::map<QString, double>::iterator i = bonuses.begin(); i != bonuses.end(); ++i)
		initItem(createItem(), i->first, i->second);
	emit listChanged();
}
