#include "event.h"

#include <QBuffer>
#include "startlist.h"
#include "xml/xmleventhandler.h"

using std::vector;

XkorEvent::XkorEvent(QString filename) throw(XkorFileNotFoundException)
{
	QFile * f = new QFile(filename);
	if(!f->exists())
	{
		std::string err = "File ‘";
		err += filename.toStdString();
		err += "’ not found by XkorEvent::XkorEvent(const QString &)";
		throw XkorFileNotFoundException(err, QObject::tr("event file"), filename);
	}
	loadFile(f);
	delete f;
}

XkorEvent::XkorEvent(QIODevice * dev)
{
	loadFile(dev);
}

void XkorEvent::loadFile(QIODevice * dev)
{
	QXmlInputSource * in = new QXmlInputSource(dev);
	
	// parse the XML file
	QXmlSimpleReader r;
	XkorXmlEventHandler * h = new XkorXmlEventHandler;
	r.setContentHandler(h);
	r.parse(in, false);
	
	name = h->getName();
	sportname = h->getSport();
	startLists = h->getStartLists();
	groups = h->getGroups();
	rpfilename = h->getRpbonus();
	outputType = h->getOutput();
	
	bonuses = XkorConfig(rpfilename);
	
	delete h;
	delete in;
}

QString XkorEvent::getName()
{
	return name;
}

QString XkorEvent::getConfigFileName()
{
	return rpfilename;
}

QString XkorEvent::getSport()
{
	return sportname;
}

vector<XkorGroup> XkorEvent::getGroups()
{
	return groups;
}

vector<QString> XkorEvent::getStartLists()
{
	return startLists;
}

QString XkorEvent::getOutputType()
{
	return outputType;
}

XkorResults XkorEvent::makeStartLists(XkorXmlIndex results_ind)
{
	XkorResults rval;
	XkorStartList uberstartlist, temp;
	
	// make start lists for each file and dump athletes into the überstartlist
	for(vector<QString>::iterator i = startLists.begin(); i != startLists.end(); ++i)
	{
		temp = XkorStartList(results_ind.lookup(*i));
		set<XkorAthlete> a = temp.getAthletes();
		for(set<XkorAthlete>::iterator j = a.begin(); j != a.end(); ++j)
			uberstartlist.addAthlete(*j);
	}
	
	// now create the real start lists
	for(vector<XkorGroup>::iterator i = groups.begin(); i != groups.end(); ++i)
	{
		XkorResultsGroup currentgroup;
		for(vector<QString>::iterator j = i->athletes.begin(); j != i->athletes.end(); ++j)
		{
			XkorAthlete a = uberstartlist.getAthleteBySN(*j);
			a.rpBonus = bonuses.bonus(a.nation);
			currentgroup.athletes.push_back(a);
		}
		currentgroup.name = i->name;
		rval.groups.push_back(currentgroup);
	}
	
	// copy over settings from the event
	rval.outputType = outputType;
	rval.name = name;
	
	return rval;
}

void XkorEvent::setHeadtohead(bool h2h)
{
	headtohead = h2h;
}

QString XkorEvent::getStartListDirectory()
{
	return bonuses.getStartListDirectory();
}
