#ifndef CURLING_H
#define CURLING_H

#include "outputformats/outputformatbase.h"

struct XkorOutputCurling : XkorAbstractOutputFormat
{
	public:
		virtual QString output(XkorResults * r, XkorSport & s)
		{
			QString rval;
			if(s.countValues() < requiredValues())
				return "Sport does not support this output format";
			
			for(vector<XkorResultsGroup>::iterator i = r->groups.begin(); i != r->groups.end(); ++i)
			{
				rval += "\n" + i->name + "\n";
				int acc = 0;
				for(vector<XkorAthlete>::iterator j = i->athletes.begin(); j != i->athletes.end(); ++j)
				{
					if(acc & 1) // if we’re on the second team in a match
					{
						vector<XkorAthlete>::iterator prev = j;
						--prev;
						double score1 = s.h2hScore(0, prev->skill, prev->style, prev->rpBonus, j->skill, j->style, j->rpBonus);
						double score2 = s.h2hScore(0, j->skill, j->style, j->rpBonus, prev->skill, prev->style, prev->rpBonus);
						if(score1 == score2) // there is no “tie” in “curling”
						{
							double extraends1 = s.h2hScore(1, prev->skill, prev->style, prev->rpBonus, j->skill, j->style, j->rpBonus);
							double extraends2 = s.h2hScore(1, j->skill, j->style, j->rpBonus, prev->skill, prev->style, prev->rpBonus);
							if(extraends1 > extraends2)
								score1 += s.h2hScore(2, prev->skill, prev->style, prev->rpBonus, j->skill, j->style, j->rpBonus);
							else
								score2 += s.h2hScore(2, j->skill, j->style, j->rpBonus, prev->skill, prev->style, prev->rpBonus);
						}
						rval += prev->name + " " + QString::number(score1, 'f', s.displayDigits(0)) + "–" + QString::number(score2, 'f', s.displayDigits(0)) + " " + j->name + "\n";
					}
					++acc;
				}
			}
			return rval;
		}
		
		virtual ~XkorOutputCurling() {;;;}
	
	protected:
		virtual QString individualResult(XkorSport &, double, double, double) { return QString(); } // unused
		
		virtual uint requiredValues() { return 3; }
};

#endif
