#ifndef FOOTBALL_H
#define FOOTBALL_H

struct XkorOutputFootball
{
	static QString output(XkorResults * r, bool allowExtraTime, bool allowPenalties, bool useStyleMods)
	{
		QString rval;
		for(vector<XkorResultsGroup>::iterator i = r->groups.begin(); i != r->groups.end(); ++i)
		{
			rval += i->name;
			rval += "\n";
			int acc = 0;
			for(vector<XkorAthlete>::iterator j = i->athletes.begin(); j != i->athletes.end(); ++j)
			{
				if(acc & 1) // only give output for every other athlete
				{
					// find the last athlete
					vector<XkorAthlete>::iterator prev = j;
					--prev;
					
					// calculate style effect
					double styleEffect = 0;
					if(useStyleMods)
					{
						double minStyleEffect = (prev->results[0] < j->results[0] ? prev->results[0] : j->results[0]);
						styleEffect = (minStyleEffect >= -(prev->results[3] + j->results[3]) ? prev->results[3] + j->results[3] : -minStyleEffect);
					}
					
					rval += prev->name;
					rval += " ";
					rval += QString::number(prev->results[0] + styleEffect, 'f', r->precision[0]);
					rval += "–";
					rval += QString::number(j->results[0] + styleEffect, 'f', r->precision[0]);
					rval += " ";
					rval += j->name;
					
					// extra time and PKs
					bool et = false, pen = false;
					if(prev->results[0] == j->results[0])
					{
						if(allowExtraTime)
							et = true;
						if((!allowExtraTime || prev->results[1] == j->results[1]) && allowPenalties)
							pen = true;
					}
					
					if(et || pen)
						rval += " (";
					if(et)
					{
						rval += QString::number(prev->results[0] + prev->results[1] + styleEffect, 'f', r->precision[1]);
						rval += "–";
						rval += QString::number(j->results[0] + j->results[1] + styleEffect, 'f', r->precision[1]);
						rval += " AET";
					}
					if(et && pen)
						rval += "; ";
					if(pen)
					{
						double t1score = 0, t2score = 0; // PK scores
						for(int count = 0; abs(t1score - t2score) <= 5 - count; ++count) // simulate PKs
						{
							if(RandomLib::Random::Global.Fixed<double>() < prev->results[2])
								++t1score;
							if(RandomLib::Random::Global.Fixed<double>() < j->results[2])
								++t2score;
							if(count >= 5)
								--count;
						}
						
						rval += QString::number(t1score);
						rval += "–";
						rval += QString::number(t2score);
						rval += " PKs";
					}
					if(et || pen)
						rval += ")";
					rval += "\n";
				}
				++acc;
			}
		}
		return rval;
	}
};

#endif
