#ifndef PGS_H
#define PGS_H

#include "outputformats/outputformatbase.h"

struct XkorOutputPGS : public XkorAbstractOutputFormat 
{
	public:
		virtual QString output(XkorResults * r, XkorSport & s)
		{
			QString rval;
			if(s.countValues() < requiredValues())
				return "Sport does not support this output format";
			
			for(vector<XkorResultsGroup>::iterator i = r->groups.begin(); i != r->groups.end(); ++i)
			{
				rval += "\n" + i->name + "\n";
				int acc = 0;
				for(vector<XkorAthlete>::iterator j = i->athletes.begin(); j != i->athletes.end(); ++j)
				{
					if(acc & 1) // if we’re on the second team in a tie
					{
						vector<XkorAthlete>::iterator prev = j;
						--prev;
						
						// run 1
						QString score1run1 = individualResult(s, prev->skill, prev->style, prev->rpBonus);
						QString score2run1 = individualResult(s, j->skill, j->style, j->rpBonus);
						
						double diff1run1 = 0, diff2run1 = 0;
						bool winner1;
						double penaltyTime = s.individualScore(3, 0, 0, 0);
						
						if(runFailed(score1run1) && !runFailed(score2run1))
						{
							diff1run1 = penaltyTime;
							winner1 = true; // 2
						}
						else if(runFailed(score2run1) && !runFailed(score1run1))
						{
							diff2run1 = penaltyTime;
							winner1 = false; // 1
						}
						else if(runFailed(score1run1) && runFailed(score2run1))
							winner1 = (s.individualScore(0, prev->skill, prev->style, prev->rpBonus) < s.individualScore(0, prev->skill, prev->style, prev->rpBonus)); // who got the farthest?
						else if(score1run1.toDouble() > score2run1.toDouble())
						{
							diff1run1 = score1run1.toDouble() - score2run1.toDouble();
							winner1 = true; // 2
						}
						else
						{
							diff2run1 = score2run1.toDouble() - score1run1.toDouble();
							winner1 = false; // 1
						}
						
						// adjust penalty time
						double penalty1 = (diff1run1 > penaltyTime) ? penaltyTime : diff1run1;
						double penalty2 = (diff2run1 > penaltyTime) ? penaltyTime : diff2run1;
						
						// run 2
						QString score1run2 = individualResult(s, prev->skill, prev->style, prev->rpBonus);
						QString score2run2 = individualResult(s, j->skill, j->style, j->rpBonus);
						
						double diff1run2 = 0, diff2run2 = 0;
						bool winner2;
						
						if(runFailed(score1run2) && !runFailed(score2run2))
							winner2 = true; // 2
						else if(runFailed(score2run2) && !runFailed(score1run2))
							winner2 = false; // 1
						else if(runFailed(score1run2) && runFailed(score2run2))
							winner2 = (s.individualScore(0, prev->skill, prev->style, prev->rpBonus) < s.individualScore(0, prev->skill, prev->style, prev->rpBonus)); // who got the farthest?
						else if((score1run2.toDouble() + penalty1) > (score2run2.toDouble() + penalty2))
						{
							diff1run2 = (score1run2.toDouble() + penalty1) - (score2run2.toDouble() + penalty2);
							winner2 = true; // 2
						}
						else
						{
							diff2run2 = (score2run2.toDouble() + penalty2) - (score1run2.toDouble() + penalty1);
							winner2 = false; // 1
						}
						
						// now the output, finally…
						rval += formatAthlete(prev->name, prev->nation, score1run1, score1run2, diff1run1, diff1run2, !winner1, !winner2, s.displayDigits(0));
						rval += formatAthlete(j->name, j->nation, score2run1, score2run2, diff2run1, diff2run2, winner1, winner2, s.displayDigits(0));
						rval += "\n";
					}
					++acc;
				}
			}
			return rval;
		}
		
		virtual ~XkorOutputPGS() {;;;}
	
	protected:
		QString formatAthlete(QString name, QString nation, QString run1, QString run2, double diff1, double diff2, bool winner1, bool winner2, uint digits)
		{
			QString rval;
			rval += athleteName(name, nation).leftJustified(48);
			if(runFailed(run1))
				rval += run1.rightJustified(10);
			else if(winner1)
				rval += QString().rightJustified(10);
			else
				rval += ("+" + QString::number(diff1, 'f', digits)).rightJustified(10);
			if(runFailed(run2))
				rval += run2.rightJustified(10);
			else if(winner2)
				rval += QString().rightJustified(10);
			else
				rval += ("+" + QString::number(diff2, 'f', digits)).rightJustified(10);
			if(winner2)
				rval += "  Q";
			rval += "\n";
			return rval;
		}
		
		virtual QString individualResult(XkorSport & s, double skill, double style, double bonus)
		{
			QString rval;
			if(s.individualScore(1, skill, style, bonus) == 1)
				rval = "DNF";
			else if(s.individualScore(2, skill, style, bonus) == 1)
				rval = "DSQ";
			else
				rval = QString::number(s.individualScore(0, skill, style, bonus), 'f', s.displayDigits(0));
			return rval;
		}
		
		virtual uint requiredValues() { return 4; }
		
		bool runFailed(QString result)
		{
			return (result == "DNF" || result == "DSQ");
		}
};

#endif
