#ifndef PGSQUAL_H
#define PGSQUAL_H

#include "outputformats/outputformatbase.h"

struct XkorOutputPGSQual : public XkorAbstractOutputFormat
{
	public:
		virtual QString output(XkorResults * r, XkorSport & s)
		{
			QString rval;
			if(s.countValues() < requiredValues())
				return "Sport does not support this output format";
			
			for(vector<XkorResultsGroup>::iterator i = r->groups.begin(); i != r->groups.end(); ++i)
			{
				rval += "\n" + i->name + "\n";
				for(vector<XkorAthlete>::iterator j = i->athletes.begin(); j != i->athletes.end(); ++j)
				{
					QString result1, result2, total;
					result1 = individualResult(s, j->skill, j->style, j->rpBonus);
					result2 = individualResult(s, j->skill, j->style, j->rpBonus);
					
					// total result
					if(!runFailed(result1) && !runFailed(result2))
						total = timeFormat(result1.toDouble() + result2.toDouble(), s.displayDigits(0));
					
					rval += athleteName(j->name, j->nation).leftJustified(48);
					rval += result1.rightJustified(10);
					if(runFailed(result1))
						rval += QString().rightJustified(10);
					else
						rval += result2.rightJustified(10);
					rval += total.rightJustified(12);
					
					rval += "\n";
				}
			}
			return rval;
		}
		
	private:
		virtual QString individualResult(XkorSport & s, double skill, double style, double bonus)
		{
			QString rval;
			if(s.individualScore(1, skill, style, bonus) == 1)
				rval = "DNF";
			else if(s.individualScore(2, skill, style, bonus) == 1)
				rval = "DSQ";
			else
				rval = QString::number(s.individualScore(0, skill, style, bonus), 'f', s.displayDigits(0));
			return rval;
		}
		
		uint requiredValues() { return 3; }
		
		bool runFailed(QString result)
		{
			return (result == "DNF" || result == "DSQ");
		}
};

#endif
