#ifndef SPEEDSKATETEAMPURSUIT_H
#define SPEEDSKATETEAMPURSUIT_H

#include "outputformats/outputformatbase.h"

struct XkorOutputSpeedSkateTeamPursuit : public XkorAbstractOutputFormat 
{
	public:
		virtual QString output(XkorResults * r, XkorSport & s)
		{
			QString rval;
			if(s.countValues() < requiredValues())
				return "Sport does not support this output format";
			
			for(vector<XkorResultsGroup>::iterator i = r->groups.begin(); i != r->groups.end(); ++i)
			{
				rval += "\n" + i->name + "\n";
				int acc = 0;
				for(vector<XkorAthlete>::iterator j = i->athletes.begin(); j != i->athletes.end(); ++j)
				{
					if(acc & 1) // if we’re on the second team in a tie
					{
						vector<XkorAthlete>::iterator prev = j;
						--prev;
						
						// run 1
						QString score1, score2;
						do
						{
							score1 = individualResult(s, prev->skill, prev->style, prev->rpBonus);
							score2 = individualResult(s, j->skill, j->style, j->rpBonus);
						}
						while(runFailed(score1) && runFailed(score2)); // only one team can be overtaken
						
						if(runFailed(score1))
							score2 = "WOT";
						else if(runFailed(score2))
							score1 = "WOT";
						
						rval += athleteName(prev->name, prev->nation).leftJustified(48);
						rval += score1.rightJustified(10);
						rval += "\n";
						
						rval += athleteName(j->name, j->nation).leftJustified(48);
						rval += score2.rightJustified(10);
						rval += "\n\n";
					}
					++acc;
				}
			}
			return rval;
		}
		
		virtual ~XkorOutputSpeedSkateTeamPursuit() {;;;}
	
	protected:
		virtual QString individualResult(XkorSport & s, double skill, double style, double bonus)
		{
			QString rval;
			double result = s.individualScore(0, skill, style, bonus);
			if(result == 109300)
				rval = "LOT";
			else
				rval = timeFormat(result, s.displayDigits(0));
			return rval;
		}
		
		virtual uint requiredValues() { return 1; }
		
		bool runFailed(QString result)
		{
			return (result == "LOT");
		}
};

#endif
