#include "rpfile.h"

#include "xml/xmlconfighandler.h"

XkorConfig::XkorConfig(const QString & filename) throw(XkorFileNotFoundException)
{
	// set up the input source
	QFile * f = new QFile(filename);
	if(!f->exists())
	{
		std::string err = "File ‘";
		err += filename.toStdString();
		err += "’ not found by XkorConfig::XkorConfig(const QString &)";
		throw XkorFileNotFoundException(err, QObject::tr("config file"), filename);
	}
	QXmlInputSource * in = new QXmlInputSource(f);
	
	// parse the XML file
	QXmlSimpleReader r;
	XkorXmlConfigHandler * h = new XkorXmlConfigHandler;
	r.setContentHandler(h);
	r.parse(in, false);
	
	this->name = h->getName();
	this->bonuses = h->getBonuses();
	this->startListDirectory = h->getStartListDirectory();
	
	delete h;
	delete in;
	delete f;
}

double XkorConfig::bonus(const QString & code)
{
	return bonuses[code];
}

std::map<QString, double> XkorConfig::getAllBonuses()
{
	return bonuses;
}

QString XkorConfig::getName()
{
	return name;
}

QString XkorConfig::getStartListDirectory()
{
	return startListDirectory;
}
