#include "sport.h"

#include "RandomLib/Random.hpp"
#include "xml/xmlsporthandler.h"

using namespace std;

XkorSport::XkorSport(QString filename)
{
	// seed the RNG
	RandomLib::Random::Global.Reseed();
	
	// set up the input source
	QFile * f = new QFile(filename);
	QXmlInputSource * in = new QXmlInputSource(f);
	
	// parse the XML file
	QXmlSimpleReader r;
	XkorXmlSportHandler * h = new XkorXmlSportHandler;
	r.setContentHandler(h);
	r.parse(in, false);
	
	name = h->getName();
	dataPoints = h->getDataPoints();
	digits = h->getDisplayDigits();
	prec = h->getPrecision();
	scoreType = h->getScoreType();
	
	delete h;
	delete in;
	delete f;
}

double XkorSport::h2hScore(uint index, double skill, double style, double rp, double oppSkill, double oppStyle, double oppRp)
{
	double skill1 = skill * 0.9 + rp * 0.1;
	double skill2 = oppSkill * 0.9 + oppRp * 0.1;
	double skillDiff = skill1 - skill2;
	return score(index, 0.5 + skillDiff / 2, (style + oppStyle) / 2, 1.02, 2.4, 3.8, false);
}

double XkorSport::individualScore(uint index, double skill, double style, double rp)
{
	skill = skill * 0.9 + rp * 0.1;
	skill = 0.5 - (0.5 - skill > 0 ? 1 : -1) * pow(abs(0.5 - skill), 1 / 4.0) / pow(2, 3 / 4.0);
	return score(index, skill, style, 1.4, 2, 4, true);
}

double XkorSport::rand_kumaraswamy(double a, double b, bool skew) // skew = true : skewed toward 1; false : skewed toward 0
{
	double r = RandomLib::Random::Global.Fixed<double>();
	double rval;
	
	if(skew)
		rval = pow(1 - pow(1 - r, 1 / b), 1 / a);
	else
		rval = 1 - pow(1 - pow(1 - r, 1 / a), 1 / b);
	return rval;
}

double XkorSport::rand_triangular(double a, double c, double b)
{
	double r = RandomLib::Random::Global.Fixed<double>();
	
	// now do the transformation
	double rval;
	
	if(r < (a - c) / (a - b)) // lower half of the distribution
		rval = sqrt(r * (b - a) * (c - a)) + a;
	else // upper half
		rval = b - sqrt((1 - r) * (b - a) * (b - c));
	return rval;
}

double XkorSport::score(uint index, double skill, double style, double minConstant, double midConstant, double maxConstant, bool skew)
{
	double rand = 0;
	
	if(scoreType.at(index) == "rank")
	{
		double scorSkill = skill;
		double a = (scorSkill > 0.5 ? (scorSkill - 0.5) * 2 * (maxConstant - midConstant) + midConstant : scorSkill * 2 * (midConstant - minConstant) + minConstant);
		double b = (scorSkill < 0.5 ? (0.5 - scorSkill) * 2 * (maxConstant - midConstant) + midConstant : (1 - scorSkill) * (midConstant - minConstant) + minConstant);
		rand = rand_kumaraswamy(a, b, skew);
	}
	else if(scoreType.at(index) == "style")
	{
		double scorSkill = style;
		double a = (scorSkill > 0.5 ? (scorSkill - 0.5) * (maxConstant - minConstant) + minConstant : minConstant);
		double b = (scorSkill < 0.5 ? (0.5 - scorSkill) * (maxConstant - minConstant) + minConstant : minConstant);
		rand = rand_kumaraswamy(a, b, skew);
	}
	else if(scoreType.at(index) == "uniform")
		rand = RandomLib::Random::Global.Fixed<double>();
	
	return (long)(transformNumber(rand, index) / precision(index)) * precision(index);
}

double XkorSport::transformNumber(double x, uint index) const
{
	map<double, double>::const_iterator a, b;
	for(map<double, double>::const_iterator j = dataPoints[index].begin(); j != dataPoints[index].end(); ++j)
	{
		map<double, double>::const_iterator next = j;
		if(++next == dataPoints[index].end())
		{
			// b is j; a is the point before j
			a = b = j;
			--a;
			break;
		}
		else if(x < next->first)
		{
			a = j;
			b = next;
			break;
		}
	}
	return a->second + (b->second - a->second) / (b->first - a->first) * (x - a->first);
}
