#include "startlisteditor/athletewidget.h"

#include <QFile>
#include <QFileDialog>
#include <QHeaderView>
#include <QTextStream>
#include "startlisteditor/athletedelegate.h"

XkorAthleteWidget::XkorAthleteWidget()
{
	treeWidget->setColumnCount(4);
	treeWidget->setSortingEnabled(true);
	treeWidget->setItemDelegate(new XkorAthleteDelegate);
	treeWidget->sortItems(0, Qt::AscendingOrder);
	treeWidget->setHeaderLabels(QStringList() << tr("Athlete") << tr("Nation") << tr("Skill") << tr("Style"));
	
	// set the column widths
	treeWidget->header()->setResizeMode(0, QHeaderView::Stretch);
	treeWidget->header()->setResizeMode(1, QHeaderView::Stretch);
	treeWidget->header()->setResizeMode(2, QHeaderView::Fixed);
	treeWidget->header()->setResizeMode(3, QHeaderView::Fixed);
	treeWidget->header()->resizeSection(2, 100);
	treeWidget->header()->resizeSection(3, 100);
	
	importAction = new QAction(QIcon(":/icons/document-import"), tr("Import from text file"), this);
	importAction->setEnabled(true);
	connect(importAction, SIGNAL(triggered()), this, SLOT(importAthletes()));
	
	importButton = new QToolButton;
	importButton->setDefaultAction(importAction);
	
	setupLayout();
}

std::set<XkorAthlete> XkorAthleteWidget::athletes()
{
	std::set<XkorAthlete> rval;
	for(QTreeWidgetItemIterator i(treeWidget); *i; ++i)
	{
		XkorAthlete a;
		a.name = (*i)->text(0);
		a.shortname = (*i)->data(0, 1093).toString();
		a.nation = (*i)->text(1);
		a.skill = (*i)->text(2).toDouble();
		a.style = (*i)->text(3).toDouble();
		rval.insert(a);
	}
	return rval;
}

void XkorAthleteWidget::importAthletes()
{
	isInUse = true;
	QString filename = QFileDialog::getOpenFileName(this, tr("Open semicolon-delimited athlete file"), ".", tr("Text files (*.txt)"));
	if(filename != "")
	{
		QFile f(filename);
		if(!f.open(QIODevice::ReadOnly | QIODevice::Text))
			return;
		
		QTextStream ist(&f);
		
		while(!ist.atEnd())
		{
			QString line = ist.readLine();
			QStringList l = line.split(";");
			if(l.size() == 3)
			{
				QString athleteName = l[0].trimmed();
				QString athleteNation = l[1].trimmed();
				QString athleteSkill = l[2].trimmed();
				
				initItem(createItem(), athleteName, athleteName, athleteNation, athleteSkill.toDouble(), 0.0);
			}
		}
	}
	isInUse = false;
	emit listChanged();
}

void XkorAthleteWidget::initItem(QTreeWidgetItem * item, QString athleteName, QString shortName, QString nation, double skill, double style)
{
	item->setText(0, athleteName);
	item->setData(0, 1093, shortName);
	item->setText(1, nation);
	item->setText(2, QString::number(skill));
	item->setText(3, QString::number(style));
}

void XkorAthleteWidget::setAthletes(std::set<XkorAthlete> athletes)
{
	treeWidget->clear();
	for(std::set<XkorAthlete>::iterator i = athletes.begin(); i != athletes.end(); ++i)
	{
		QTreeWidgetItem * item = new QTreeWidgetItem(treeWidget);
		item->setFlags(item->flags() | Qt::ItemIsEditable);
		initItem(item, i->name, i->shortname, i->nation, i->skill, i->style);
	}
	emit listChanged();
}

void XkorAthleteWidget::setupLayout()
{
	layout = new QGridLayout(this);
	layout->addWidget(treeWidget, 0, 0, 7, 1);
	layout->addWidget(insertButton, 1, 1);
	layout->addWidget(importButton, 3, 1);
	layout->addWidget(deleteButton, 5, 1);
}



