#include "startlisteditor.h"

#include <QFile>
#include <QFileDialog>
#include <QFormLayout>
#include <QGroupBox>
#include <QMessageBox>
#include <QTextCodec>
#include <QTextStream>
#include <QToolButton>
#include "startlist.h"

XkorStartListEditor::XkorStartListEditor(QWidget * parent) : QWidget(parent)
{
	fileIsModified = false;
	
	startListName = new QLineEdit;
	
	// tree widget
	athletes = new XkorAthleteWidget;
	
	// form layout
	QFormLayout * form = new QFormLayout;
	form->addRow(tr("Name:"), startListName);
	
	// tree widget layout
	QGroupBox * agroup = new QGroupBox(tr("Athletes"));
	QHBoxLayout * alayout = new QHBoxLayout;
	alayout->addWidget(athletes);
	agroup->setLayout(alayout);
	
	// layout
	QVBoxLayout * layout = new QVBoxLayout(this);
	layout->addLayout(form, 0);
	layout->addWidget(agroup, 1);
	
	connect(startListName, SIGNAL(textChanged(QString)), this, SLOT(setModified()));
	connect(athletes, SIGNAL(listChanged()), this, SLOT(setModified()));
}

bool XkorStartListEditor::okayToLoad()
{
	if(fileIsModified)
	{
		int r = QMessageBox::warning(this, tr("xkoranate"), tr("The start list file has been modified.\nDo you want to save your changes?"), QMessageBox::Yes | QMessageBox::Default, QMessageBox::No, QMessageBox::Cancel | QMessageBox::Escape);
		if(r == QMessageBox::Cancel)
			return false;
	}
	return true; // if the current file hasn’t been modified, or if the user clicked Yes or No
}

void XkorStartListEditor::openFile()
{
	if(okayToLoad())
	{
		QString filename = QFileDialog::getOpenFileName(this, tr("Open start list file"), ".", tr("XML files (*.xml)"));
		
		XkorStartList sl(filename);
		startListName->setText(sl.getName());
		
		athletes->setAthletes(sl.getAthletes());
		
		currentFileName = filename;
		emit fileChanged(filename);
		setModified(false);
	}
}

void XkorStartListEditor::saveFile(QString filename)
{	
	if(filename == QString()) // if no filename was specified
	{
		if(currentFileName == QString()) // still “Untitled”?
			saveFileAs();
		else
			filename = currentFileName;
	}
	QFile f(filename);
	writeFile(&f);
	currentFileName = filename;
	emit fileChanged(filename);
	setModified(false);
}

void XkorStartListEditor::saveFileAs()
{
	QString filename = QFileDialog::getSaveFileName(this, tr("Save event file"), ".", tr("XML files (*.xml)"));
	if(filename != QString())
		saveFile(filename);
}

void XkorStartListEditor::setModified(bool isModified)
{
	fileIsModified = isModified;
	emit fileEdited(isModified);
}

void XkorStartListEditor::writeFile(QIODevice * dev)
{
	dev->open(QIODevice::WriteOnly);
	
	QTextStream ost(dev);
	ost.setCodec(QTextCodec::codecForName("UTF-8"));
	
	ost << "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<startlist>\n";
	ost << "\t<name>" << startListName->text() << "</name>\n";
	
	std::set<XkorAthlete> a = athletes->athletes();
	for(std::set<XkorAthlete>::iterator i = a.begin(); i != a.end(); ++i)
	{
		ost << "\t<athlete>\n";
		ost << "\t\t<athleteName>" << i->name << "</athleteName>\n";
		if(i->shortname == QString())
			ost << "\t\t<shortName>" << i->name << "</shortName>\n";
		else // we have a special shortname set
			ost << "\t\t<shortName>" << i->shortname << "</shortName>\n";
		ost << "\t\t<nation>" << i->nation << "</nation>\n";
		ost << "\t\t<skill>" << i->skill << "</skill>\n";
		ost << "\t\t<style>" << i->style << "</style>\n";
		ost << "\t</athlete>\n";
	}
	ost << "</startlist>\n";
}
