#include "tablegenerator/matchwidget.h"

#include <QFileDialog>
#include <QGridLayout>
#include <QHeaderView>
#include <QRegExp>
#include <QTextStream>
#include "tablegenerator/matchdelegate.h"

XkorMatchWidget::XkorMatchWidget()
{
	treeWidget->setColumnCount(4);
	treeWidget->setItemDelegate(new XkorMatchDelegate);
	treeWidget->setHeaderLabels(QStringList() << tr("Home") << tr("Score") << tr("Score") << tr("Away"));
	
	// set the column widths
	treeWidget->header()->setResizeMode(0, QHeaderView::Stretch);
	treeWidget->header()->setResizeMode(1, QHeaderView::Fixed);
	treeWidget->header()->setResizeMode(2, QHeaderView::Fixed);
	treeWidget->header()->setResizeMode(3, QHeaderView::Stretch);
	treeWidget->header()->resizeSection(1, 50);
	treeWidget->header()->resizeSection(2, 50);
	
	importAction = new QAction(QIcon(":/icons/document-import"), tr("Import from text file"), this);
	importAction->setEnabled(true);
	connect(importAction, SIGNAL(triggered()), this, SLOT(importMatches()));
	
	importButton = new QToolButton;
	importButton->setDefaultAction(importAction);
	
	setupLayout();
}

void XkorMatchWidget::importMatches()
{
	isInUse = true;
	QString filename = QFileDialog::getOpenFileName(this, tr("Open results file"), ".", tr("Text files (*.txt)"));
	if(filename != "")
	{
		QFile f(filename);
		if(!f.open(QIODevice::ReadOnly | QIODevice::Text))
			return;
		
		QTextStream ist(&f);
		
		while(!ist.atEnd())
		{
			QString line = ist.readLine();
			QRegExp rx("(.+) ([0-9]+)[-–:]([0-9]+) (.+)"); // match scores of form Aquilla 3–1 Busby, with en dash, hyphen-minus, or colon as delimiter
			if(rx.indexIn(line) != -1) // if we matched
				initItem(createItem(), rx.cap(1), rx.cap(2).toDouble(), rx.cap(3).toDouble(), rx.cap(4));
		}
	}
	isInUse = false;
	emit listChanged();
}

void XkorMatchWidget::initItem(QTreeWidgetItem * item, QString home, double homeScore, double awayScore, QString away)
{
	item->setText(0, home);
	item->setText(1, QString::number(homeScore));
	item->setText(2, QString::number(awayScore));
	item->setText(3, away);
	
	item->setTextAlignment(0, Qt::AlignRight);
	item->setTextAlignment(1, Qt::AlignRight);
}

std::vector<XkorTableMatch> XkorMatchWidget::matches()
{
	std::vector<XkorTableMatch> rval;
	for(QTreeWidgetItemIterator i(treeWidget); *i; ++i)
		rval.push_back(XkorTableMatch((*i)->text(0), (*i)->text(3), (*i)->text(1).toDouble(), (*i)->text(2).toDouble()));
	return rval;
}

void XkorMatchWidget::setMatches(std::vector<XkorTableMatch> m)
{
	isInUse = true;
	clear();
	for(std::vector<XkorTableMatch>::iterator i = m.begin(); i != m.end(); ++i)
		initItem(createItem(), i->team1, i->score1, i->score2, i->team2);
	isInUse = false;
	emit listChanged();
}

void XkorMatchWidget::setupLayout()
{
	layout = new QGridLayout(this);
	layout->addWidget(treeWidget, 0, 0, 11, 1);
	layout->addWidget(moveUpButton, 1, 1);
	layout->addWidget(insertButton, 3, 1);
	layout->addWidget(importButton, 5, 1);
	layout->addWidget(deleteButton, 7, 1);
	layout->addWidget(moveDownButton, 9, 1);
}
