#ifndef TABLEGENERATOR_H
#define TABLEGENERATOR_H

#include <QDoubleSpinBox>
#include <QTextEdit>

#include "tablegenerator/matchwidget.h"
#include "tablegenerator/sortcriteriawidget.h"
#include "tablegenerator/table.h"
#include "tablegenerator/tablecolumnswidget.h"

class XkorTableGenerator : public QWidget
{
	Q_OBJECT

	private:
		QTextDocument * doc;
		QTextEdit * textedit;
		QDoubleSpinBox * pointsForWin, * pointsForDraw, * pointsForLoss;
		XkorMatchWidget * mw;
		XkorSortCriteriaWidget * scw;
		XkorTableColumnsWidget * tcw;
		XkorTable t;
		QString currentFileName;
		bool fileIsModified;
		
		bool okayToLoad();
		void writeFile(QIODevice * dev);
		
	public:
		XkorTableGenerator(QWidget * parent = 0);
		~XkorTableGenerator();
	signals:
		void fileChanged(QString filename); // loaded a new file
		void fileEdited(bool isModified); // changed the current file
	public slots:
		void openFile();
		void saveFile(QString filename = QString());
		void saveFileAs();
	private slots:
		void refreshTable(bool isModified = true);
		void setModified(bool isModified = true);
		void setPointsForWin(QString pts);
		void setPointsForDraw(QString pts);
		void setPointsForLoss(QString pts);
		void updateMatches();
		void updateSortCriteria();
		void updateTableColumns();
};

#endif
